Enum sprintf::parser::FormatElement
source · pub enum FormatElement {
Verbatim(String),
Format(ConversionSpecifier),
}Expand description
A part of a format string: either a string of characters to be included verbatim, or a format specifier that should be replaced based on an argument to the vsprintf call.
Variants
Verbatim(String)
Some characters that are copied to the output as-is
Format(ConversionSpecifier)
A format specifier